@@ -31,11 +31,25 @@ int main (int argc, char** argv)
 													"appointment-new");
 	n.set_timeout(3000); //3 seconds
 
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
+	try
+	{	
 	if (!n.show()) 
+#else
+	std::auto_ptr<Glib::Error> error;
+	if (!n.show(error))
+#endif
 	{
 		std::cerr << "failed to send notification" << std::endl;
 		return 1;
 	}
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
+	}
+	catch (Glib::Error& err)
+	{
+		std::cout << err.what() << std::endl;
+	}
+#endif
 	return 0;
 }
 
