@@ -37,11 +37,25 @@ int main (int argc, char** argv)
 	n.set_timeout(3000); //3 seconds
 	n.set_urgency(Notify::URGENCY_LOW);
 
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
+	try
+	{	
 	if (!n.show()) 
+#else
+	std::auto_ptr<Glib::Error> error;
+	if (!n.show(error))
+#endif
 	{
 		std::cerr << "failed to send notification" << std::endl;
 		return 1;
 	}
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
+	}
+	catch (Glib::Error& err)
+	{
+		std::cout << err.what() << std::endl;
+	}
+#endif
 	
 	kit.run();
 	
